@@ -9,7 +9,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(c2xs);
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 sub c2xs {
     eval {require "Inline/C.pm"};
@@ -92,6 +92,10 @@ sub c2xs {
 
     if($config_options->{AUTOWRAP}) {$o->{ILSM}{AUTOWRAP} = 1}
 
+    if($config_options->{BOOT}) {$o->{ILSM}{XS}{BOOT} = $config_options->{BOOT}} 
+
+    # This is what Inline::C does with the MAKE parameter ... so we'll do the same.
+    # Not sure that this achieves anything in the context of InlineX::C2XS.
     if($config_options->{MAKE}) {$o->{ILSM}{MAKE} = $config_options->{MAKE}}
 
     if($config_options->{TYPEMAPS}) {
@@ -104,18 +108,33 @@ sub c2xs {
       $o->{ILSM}{MAKEFILE}{LIBS} = $config_options->{LIBS}
     }
 
+    if($config_options->{PREFIX}) {$o->{ILSM}{XS}{PREFIX} = $config_options->{PREFIX}}
+
     bless($o, 'Inline::C');
 
     Inline::C::validate($o);
 
+    if($config_options->{AUTO_INCLUDE}) {$o->{ILSM}{AUTO_INCLUDE} .= $config_options->{AUTO_INCLUDE} . "\n"}
+
     if($config_options->{CC}) {$o->{ILSM}{MAKEFILE}{CC} = $config_options->{CC}}
 
-    if($config_options->{LD}) {$o->{ILSM}{MAKEFILE}{LD} = $config_options->{LD}}
+    if($config_options->{CCFLAGS}) {$o->{ILSM}{MAKEFILE}{CCFLAGS} = " " . $config_options->{CCFLAGS}}
 
     if($config_options->{INC}) {$o->{ILSM}{MAKEFILE}{INC} .= " $config_options->{INC}"}
 
+    if($config_options->{LD}) {$o->{ILSM}{MAKEFILE}{LD} = " " . $config_options->{LD}}
+
+    if($config_options->{LDDLFLAGS}) {$o->{ILSM}{MAKEFILE}{LDDLFLAGS} = " " . $config_options->{LDDLFLAGS}}
+
+    # Here, we'll add the MAKE parameter to $o->{ILSM}{MAKEFILE}{MAKE} ... which
+    # could be useful (given that recent versions of Extutils::MakeMaker now recognise it):
+    if($config_options->{MAKE}) {$o->{ILSM}{MAKEFILE}{MAKE} = $config_options->{MAKE}}
+
+    if($config_options->{MYEXTLIB}) {$o->{ILSM}{MAKEFILE}{MYEXTLIB} = " " . $config_options->{MYEXTLIB}}
+
+    if($config_options->{OPTIMIZE}) {$o->{ILSM}{MAKEFILE}{OPTIMIZE} = " " . $config_options->{OPTIMIZE}}
+
     if(!$need_inline_h) {$o->{ILSM}{AUTO_INCLUDE} =~ s/#include "INLINE.h"//i}
-    if($config_options->{AUTO_INCLUDE}) {$o->{ILSM}{AUTO_INCLUDE} .= $config_options->{AUTO_INCLUDE} . "\n"} 
 
     _build($o, $need_inline_h);
 
@@ -148,7 +167,7 @@ __END__
 
 =head1 NAME
 
-InlineX::C2XS - create an XS file from Inline C code.
+InlineX::C2XS - Convert from Inline C code to XS.
 
 =head1 SYNOPSIS
 
@@ -230,7 +249,8 @@ InlineX::C2XS - create an XS file from Inline C code.
  function
 
  The created XS file, when packaged with the '.pm' file, an
- appropriate 'Makefile.PL', and 'INLINE.h' (if it's needed), can be 
+ appropriate 'Makefile.PL' (which can also be auto-generated by setting
+ the WRITE_MAKEFILE_PL hash key), and 'INLINE.h' (if it's needed), can be 
  used to build the module in the usual way - without any dependence
  upon the Inline::C module.
 
@@ -239,6 +259,14 @@ InlineX::C2XS - create an XS file from Inline C code.
  As regards the optional fourth argument to c2xs(), the following hash
  keys are recognised:
 
+  AUTO_INCLUDE
+   The value specified is automatically inserted into the generated XS
+   file. (Also, the specified include will be parsed iff AUTOWRAP
+   is set to a true value.) eg:
+
+    AUTO_INCLUDE => '#include <my_header.h>',
+  ----
+
   AUTOWRAP
    Set this to a true value to enable Inline::C's AUTOWRAP capability.
    (There's no point in specifying a false value, as "false" is the 
@@ -247,6 +275,110 @@ InlineX::C2XS - create an XS file from Inline C code.
     AUTOWRAP => 1,
   ----
 
+ BOOT
+   Specifies C code to be executed in the XS BOOT section. Corresponds
+   to the XS parameter. eg:
+
+    BOOT => 'printf("Hello .. from bootstrap\n");',
+  ----
+
+  BUILD_NOISY
+   Is set to a true value, by default. Setting to a false value will
+   mean that progress messages generated by Inline::C are suppressed. eg:
+
+    BUILD_NOISY => 0,
+  ----
+
+  CC
+   Specify the compiler you want to use. It makes sense to assign this
+   key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    CC => 'g++',
+  ----
+
+  CCFLAGS
+   Specify which compiler flags to use. (Existing value gets clobbered, so
+   you'll probably want to re-specify it.) It makes sense to assign this
+   key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    CCFLAGS => '-DMY_DEFINE ' . $Config{ccflags},
+  ----
+
+  INC
+   The value specified is added to the includes search path. It makes
+   sense to assign this key only when AUTOWRAP and/or WRITE_MAKEFILE_PL
+   are set to a true value. eg:
+
+    INC => '-I/my/includes/dir',
+  ----
+
+  LD
+   Specify the linker you want to use.It makes sense to assign this
+   key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    LD => 'g++',
+  ----
+
+  LDDLFLAGS
+   Specify which linker flags to use. (Existing value gets clobbered, so
+   you'll probably want to re-specify it.) It makes sense to assign this
+   key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    LDDLFLAGS => "$my_ldopts " . $Config{lddlflags},
+  ----
+
+  LIBS
+   The value(s) specified become the LIBS search path. It makes sense
+   to assign this key only if WRITE_MAKEFILE_PL is set to a true value.
+   (Must be an array reference.) eg
+   
+    LIBS => ['-L/somewhere -lsomelib', '-L/elsewhere -lotherlib'],
+  ----
+
+  MAKE
+   Specify the make utility you want to use. It makes sense to assign this
+   key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    MAKE => 'pmake', # I have no idea whether that will work :-)
+  ----
+
+  MYEXTLIB
+   Specifies a user compiled object that should be linked in. 
+   Corresponds to the MakeMaker parameter. It makes sense to assign this
+   key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    MYEXTLIB => '/your/path/yourmodule.so',
+  ----
+
+  OPTIMIZE
+   This controls the MakeMaker OPTIMIZE setting.It makes sense to assign
+   this key only when WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    OPTIMIZE => '-g',
+  ----
+
+  PREFIX
+   Specifies a prefix that will be automatically stripped from C 
+   functions when they are bound to Perl. eg:
+
+    PREFIX => 'FOO_',
+  ----
+
+  TYPEMAPS
+   The value(s) specified are added to the list of typemaps. It makes
+   sense to assign this key only when AUTOWRAP and/or WRITE_MAKEFILE_PL
+   are set to a true value. (Must be an array reference.) eg:
+
+    TYPEMAPS =>['my_typemap', 'my_other_typemap'],
+  ----
+
+  VERSION
+   Set this to the version number of the module. It makes sense to assign
+   this key only if WRITE_MAKEFILE_PL is set to a true value. eg:
+
+    VERSION => 0.42,
+  ----
+
   WRITE_MAKEFILE_PL
    Set this to to a true value if you want the Makefile.PL to be
    generated. (There's no point in specifying a false value, as "false"
@@ -256,77 +388,8 @@ InlineX::C2XS - create an XS file from Inline C code.
     WRITE_MAKEFILE_PL => 1,
   ----
 
-  AUTO_INCLUDE
-   The value specified is automatically inserted into the generated XS
-   file. (Also, the specified include will be parsed and acted upon iff
-   AUTOWRAP is set to a true value.) eg:
-
-    AUTO_INCLUDE => '#include <my_header.h>',
-  ----
-
-  VERSION
-   Set this to the version number of the module. It makes sense to assign
-   this key only if WRITE_MAKEFILE_PL is set to a true value. eg:
-
-    VERSION => 0.42,
-  ----
-
-  INC
-   The value specified is added to the includes search path. It makes
-   sense to assign this key only when AUTOWRAP and/or WRITE_MAKEFILE_PL
-   are set to a true value. eg:
-
-    INC => '-I/my/includes/dir',
-  ----
-
-  LIBS
-   The value(s) specified become the LIBS search path. It makes sense
-   to assign this key only if WRITE_MAKEFILE_PL is set to a true value.
-   (Must be an array reference.) eg
-   
-    LIBS => ['-L/somewhere -lsomelib', '-L/elsewhere -lotherlib'],
-  ----
-
-  TYPEMAPS
-   The value(s) specified are added to the list of typemaps. It makes
-   sense to assign this key only when AUTOWRAP and/or WRITE_MAKEFILE_PL
-   are set to a true value. (Must be an array reference.) eg:
-
-    TYPEMAPS =>['my_typemap', 'my_other_typemap'],
-  ----
-
-  BUILD_NOISY
-   Is set to a true value, by default. Setting to a false value will
-   mean that progress messages generated by Inline::C are suppressed. eg:
-
-    BUILD_NOISY => 0,
-  ----
-
-  CC
-   Specify the compiler you want to use. eg:
-
-    CC => 'g++',
-  ----
-
-  LD
-   Specify the linker you want to use. eg:
-
-    LD => 'g++',
-  ----
-
-  MAKE
-   Specify the make utility you want to use. eg:
-
-    MAKE => 'pmake', # I have no idea whether that will work :-)
-  ----
-
 =head1 TODO
 
- Add coverage (and testing) of BOOT, CCFLAGS, FILTERS, LDDLFLAGS, 
- MYEXTLIB, OPTIMIZE and PREFIX options. (This will be done soon.)
-
- Add testing of CC, LD, and MAKE options. (This will be done soon.)
-
  Improve the t_makefile_pl test script. It currently provides strong 
  indication that everything is working fine ... but is not conclusive.
  (This might take forever.)  
